@@ -21,7 +21,6 @@ from typing import Any, cast, Dict, Generator, Iterable, List, Optional, Tuple,
 
 from deepdiff import DeepHash
 
-from lightning.app.core.plugin import Plugin
 from lightning.app.core.work import LightningWork
 from lightning.app.frontend import Frontend
 from lightning.app.storage import Path
@@ -741,22 +740,6 @@ class LightningFlow:
         """
         raise NotImplementedError
 
-    def configure_plugins(self) -> Optional[List[Dict[str, Plugin]]]:
-        """Configure the plugins of this LightningFlow.
-
-        Returns a list of dictionaries mapping a plugin name to a :class:`lightning.app.core.plugin.Plugin`.
-
-        .. code-block:: python
-
-            class Flow(LightningFlow):
-                def __init__(self):
-                    super().__init__()
-
-                def configure_plugins(self):
-                    return [{"my_plugin_name": MyPlugin()}]
-        """
-        pass
-
     def state_dict(self):
         """Returns the current flow state but not its children."""
         return {
