@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,9 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import lightning.pytorch._graveyard.accelerator
 import lightning.pytorch._graveyard.callbacks
+import lightning.pytorch._graveyard.cli
 import lightning.pytorch._graveyard.core
 import lightning.pytorch._graveyard.legacy_import_unpickler
 import lightning.pytorch._graveyard.loggers
+import lightning.pytorch._graveyard.loops
+import lightning.pytorch._graveyard.profiler
+import lightning.pytorch._graveyard.strategies
 import lightning.pytorch._graveyard.trainer
-import lightning.pytorch._graveyard.training_type  # noqa: F401
+import lightning.pytorch._graveyard.training_type
+import lightning.pytorch._graveyard.utilities  # noqa: F401
