@@ -11,11 +11,27 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import sys
 from typing import Any
 
 from lightning.pytorch import LightningDataModule
 
 
+def _patch_sys_modules() -> None:
+    # TODO: Remove in v2.0.0
+    self = sys.modules[__name__]
+    sys.modules["lightning.pytorch.core.lightning"] = self
+
+
+class LightningModule:
+    # TODO: Remove in v2.0.0
+    def __init__(self, *_: Any, **__: Any) -> None:
+        raise NotImplementedError(
+            "Importing `lightning.pytorch.core.lightning.LightningModule` was deprecated in v1.7.0 and removed as of"
+            " v1.9.0. Please use `from lightning.pytorch import LightningModule` instead"
+        )
+
+
 def _on_save_checkpoint(_: LightningDataModule, __: Any) -> None:
     # TODO: Remove in v2.0.0
     raise NotImplementedError(
@@ -32,6 +48,8 @@ def _on_load_checkpoint(_: LightningDataModule, __: Any) -> None:
     )
 
 
+_patch_sys_modules()
+
 # Methods
 LightningDataModule.on_save_checkpoint = _on_save_checkpoint
 LightningDataModule.on_load_checkpoint = _on_load_checkpoint
