@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,9 +20,9 @@ from typing import Any, Dict, List, Optional, Union
 import torch
 
 import lightning.pytorch as pl
-from lightning.lite.accelerators.cuda import num_cuda_devices
-from lightning.lite.utilities.device_parser import _parse_gpu_ids
-from lightning.lite.utilities.types import _DEVICE
+from lightning.fabric.accelerators.cuda import _check_cuda_matmul_precision, num_cuda_devices
+from lightning.fabric.utilities.device_parser import _parse_gpu_ids
+from lightning.fabric.utilities.types import _DEVICE
 from lightning.pytorch.accelerators.accelerator import Accelerator
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
 
@@ -40,6 +40,7 @@ class CUDAAccelerator(Accelerator):
         """
         if device.type != "cuda":
             raise MisconfigurationException(f"Device should be GPU, got {device} instead")
+        _check_cuda_matmul_precision(device)
         torch.cuda.set_device(device)
 
     def setup(self, trainer: "pl.Trainer") -> None:
