@@ -12,27 +12,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from contextlib import contextmanager
-from typing import Any, Callable, Dict, Generator, Optional, Union
+from typing import Any, Callable, cast, Dict, Generator, Optional, Union
 
 import torch
 from torch import Tensor
 from torch.optim import LBFGS, Optimizer
+from typing_extensions import Literal
 
 import lightning.pytorch as pl
-from lightning.lite.accelerators.cuda import _patch_cuda_is_available
-from lightning.lite.utilities.types import Optimizable
+from lightning.fabric.accelerators.cuda import _patch_cuda_is_available
+from lightning.fabric.utilities.types import Optimizable
 from lightning.pytorch.plugins.precision.precision_plugin import PrecisionPlugin
-from lightning.pytorch.utilities import _TORCH_GREATER_EQUAL_1_10, AMPType, GradClipAlgorithmType
+from lightning.pytorch.utilities import GradClipAlgorithmType
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
-
-if _TORCH_GREATER_EQUAL_1_10:
-    from torch import autocast as new_autocast
-else:
-    from torch.cuda.amp import autocast as old_autocast
+from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation
 
 
-class NativeMixedPrecisionPlugin(PrecisionPlugin):
-    """Plugin for Native Mixed Precision (AMP) training with ``torch.autocast``.
+class MixedPrecisionPlugin(PrecisionPlugin):
+    """Plugin for Automatic Mixed Precision (AMP) training with ``torch.autocast``.
 
     Args:
         precision: Whether to use ``torch.float16`` (``16``) or ``torch.bfloat16`` (``'bf16'``).
@@ -40,23 +37,16 @@ class NativeMixedPrecisionPlugin(PrecisionPlugin):
         scaler: An optional :class:`torch.cuda.amp.GradScaler` to use.
     """
 
-    backend = AMPType.NATIVE
-
     def __init__(
-        self, precision: Union[str, int], device: str, scaler: Optional[torch.cuda.amp.GradScaler] = None
+        self, precision: Literal["16", 16, "bf16"], device: str, scaler: Optional[torch.cuda.amp.GradScaler] = None
     ) -> None:
-        super().__init__()
-        if precision == "bf16" and not _TORCH_GREATER_EQUAL_1_10:
-            raise MisconfigurationException(
-                "To use bfloat16 with native amp you must install torch greater or equal to 1.10."
-            )
-        if scaler is None and precision == 16:
+        self.precision = cast(Literal["16", "bf16"], str(precision))
+        if scaler is None and self.precision == "16":
             with _patch_cuda_is_available():
                 # if possible, we defer CUDA initialization to support strategies that will attempt forks
                 scaler = torch.cuda.amp.GradScaler()
-        if scaler is not None and precision == "bf16":
+        if scaler is not None and self.precision == "bf16":
             raise MisconfigurationException(f"`precision='bf16'` does not use a scaler, found {scaler}.")
-        self.precision = precision
         self.device = device
         self.scaler = scaler
 
@@ -113,12 +103,10 @@ class NativeMixedPrecisionPlugin(PrecisionPlugin):
             )
         super().clip_gradients(optimizer=optimizer, clip_val=clip_val, gradient_clip_algorithm=gradient_clip_algorithm)
 
-    def autocast_context_manager(self) -> Union["old_autocast", "new_autocast"]:
-        if _TORCH_GREATER_EQUAL_1_10:
-            # the dtype could be automatically inferred but we need to manually set it due to a bug upstream
-            # https://github.com/pytorch/pytorch/issues/67233
-            return new_autocast(self.device, dtype=torch.bfloat16 if self.precision == "bf16" else torch.half)
-        return old_autocast()
+    def autocast_context_manager(self) -> torch.autocast:
+        # the dtype could be automatically inferred but we need to manually set it due to a bug upstream
+        # https://github.com/pytorch/pytorch/issues/67233
+        return torch.autocast(self.device, dtype=torch.bfloat16 if self.precision == "bf16" else torch.half)
 
     @contextmanager
     def forward_context(self) -> Generator[None, None, None]:
@@ -136,6 +124,17 @@ class NativeMixedPrecisionPlugin(PrecisionPlugin):
             self.scaler.load_state_dict(state_dict)
 
 
+class NativeMixedPrecisionPlugin(MixedPrecisionPlugin):
+    backend = "native"
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        rank_zero_deprecation(
+            "The `NativeMixedPrecisionPlugin` class has been renamed in v1.9.0 and will be removed in"
+            " v2.0.0. Please use `lightning.pytorch.plugins.MixedPrecisionPlugin` instead."
+        )
+        super().__init__(*args, **kwargs)
+
+
 def _optimizer_handles_unscaling(optimizer: Any) -> bool:
     """Determines whether a PyTorch optimizer handles unscaling gradients in the step method rather than through the
     :class:`torch.cuda.amp.GradScaler`.
