@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,23 +15,14 @@
 
 import numpy
 
-from lightning.lite.utilities import move_data_to_device  # noqa: F401
-from lightning.lite.utilities import AMPType, LightningEnum  # noqa: F401
+from lightning.fabric.utilities import LightningEnum  # noqa: F401
+from lightning.fabric.utilities import move_data_to_device  # noqa: F401
 from lightning.pytorch.utilities.distributed import AllGatherGrad  # noqa: F401
 from lightning.pytorch.utilities.enums import GradClipAlgorithmType  # noqa: F401
 from lightning.pytorch.utilities.grads import grad_norm  # noqa: F401
 from lightning.pytorch.utilities.imports import (  # noqa: F401
-    _APEX_AVAILABLE,
     _HIVEMIND_AVAILABLE,
-    _HOROVOD_AVAILABLE,
-    _HPU_AVAILABLE,
-    _IPU_AVAILABLE,
-    _IS_WINDOWS,
     _OMEGACONF_AVAILABLE,
-    _POPTORCH_AVAILABLE,
-    _TORCH_GREATER_EQUAL_1_10,
-    _TORCH_GREATER_EQUAL_1_11,
-    _TORCH_GREATER_EQUAL_1_12,
     _TORCH_QUANTIZE_AVAILABLE,
     _TORCHVISION_AVAILABLE,
 )
