@@ -18,15 +18,15 @@ import torch
 from torch import Tensor
 from torch.nn.parallel.distributed import DistributedDataParallel
 
-from lightning.lite.utilities.distributed import _all_gather_ddp_if_available as new_all_gather_ddp_if_available
-from lightning.lite.utilities.distributed import _distributed_available as new_distributed_available
-from lightning.lite.utilities.distributed import _gather_all_tensors as new_gather_all_tensors
-from lightning.lite.utilities.distributed import (
+from lightning.fabric.utilities.distributed import _all_gather_ddp_if_available as new_all_gather_ddp_if_available
+from lightning.fabric.utilities.distributed import _distributed_available as new_distributed_available
+from lightning.fabric.utilities.distributed import _gather_all_tensors as new_gather_all_tensors
+from lightning.fabric.utilities.distributed import (
     _get_default_process_group_backend_for_device as new_get_default_process_group_backend_for_device,
 )
-from lightning.lite.utilities.distributed import _init_dist_connection as new_init_dist_connection
-from lightning.lite.utilities.distributed import _sync_ddp as new_sync_ddp
-from lightning.lite.utilities.distributed import _sync_ddp_if_available as new_sync_ddp_if_available
+from lightning.fabric.utilities.distributed import _init_dist_connection as new_init_dist_connection
+from lightning.fabric.utilities.distributed import _sync_ddp as new_sync_ddp
+from lightning.fabric.utilities.distributed import _sync_ddp_if_available as new_sync_ddp_if_available
 from lightning.pytorch.utilities.rank_zero import rank_zero_debug, rank_zero_deprecation, rank_zero_info
 
 
@@ -156,7 +156,7 @@ def _collect_states_on_rank_zero(state: Dict[str, Any]) -> Dict[int, Any]:
 def all_gather_ddp_if_available(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.all_gather_ddp_if_available` has been deprecated in v1.8.0 and will"
-        " be removed in v1.10.0. This function is internal but you can copy over its implementation."
+        " be removed in v2.0.0. This function is internal but you can copy over its implementation."
     )
     return new_all_gather_ddp_if_available(*args, **kwargs)
 
@@ -164,7 +164,7 @@ def all_gather_ddp_if_available(*args: Any, **kwargs: Any) -> Any:
 def distributed_available() -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.distributed_available` has been deprecated in v1.8.0 and will"
-        " be removed in v1.10.0. This function is internal but you can copy over its implementation."
+        " be removed in v2.0.0. This function is internal but you can copy over its implementation."
     )
     return new_distributed_available()
 
@@ -172,7 +172,7 @@ def distributed_available() -> Any:
 def gather_all_tensors(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.gather_all_tensors` has been deprecated in v1.8.0 and will"
-        " be removed in v1.10.0. This function is internal but you can copy over its implementation."
+        " be removed in v2.0.0. This function is internal but you can copy over its implementation."
     )
     return new_gather_all_tensors(*args, **kwargs)
 
@@ -184,7 +184,7 @@ class AllGatherGrad(torch.autograd.Function):
 
     .. deprecated:: v1.8.0
         This function has been deprecated in v1.8.0 in favor of :func:`torch.distributed.nn.functional.all_gather` and
-        will be removed in v1.10.0.
+        will be removed in v2.0.0.
     """
 
     @staticmethod
@@ -194,7 +194,7 @@ class AllGatherGrad(torch.autograd.Function):
         group: Optional["torch.distributed.ProcessGroup"] = None,
     ) -> Tensor:
         rank_zero_deprecation(
-            "`AllGatherGrad` has been deprecated in v1.8.0 and will be removed in v1.10.0."
+            "`AllGatherGrad` has been deprecated in v1.8.0 and will be removed in v2.0.0."
             " Use `torch.distributed.nn.functional.all_gather` instead.",
             stacklevel=6,
         )
@@ -214,8 +214,8 @@ class AllGatherGrad(torch.autograd.Function):
 def get_default_process_group_backend_for_device(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.get_default_process_group_backend_for_device` has been deprecated"
-        " in v1.8.0 and will be removed in v1.10.0. This function is internal but you can copy over its implementation."
-        " `lightning.lite.utilities.distributed.get_default_process_group_backend_for_device` instead."
+        " in v1.8.0 and will be removed in v2.0.0. This function is internal but you can copy over its implementation."
+        " `lightning.fabric.utilities.distributed.get_default_process_group_backend_for_device` instead."
     )
     return new_get_default_process_group_backend_for_device(*args, **kwargs)
 
@@ -223,7 +223,7 @@ def get_default_process_group_backend_for_device(*args: Any, **kwargs: Any) -> A
 def init_dist_connection(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.init_dist_connection` has been deprecated in v1.8.0 and will"
-        " be removed in v1.10.0. This function is internal but you can copy over its implementation."
+        " be removed in v2.0.0. This function is internal but you can copy over its implementation."
     )
     return new_init_dist_connection(*args, **kwargs)
 
@@ -231,7 +231,7 @@ def init_dist_connection(*args: Any, **kwargs: Any) -> Any:
 def sync_ddp(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.sync_ddp` has been deprecated in v1.8.0 and will"
-        " be removed in v1.10.0. This function is internal but you can copy over its implementation."
+        " be removed in v2.0.0. This function is internal but you can copy over its implementation."
     )
     return new_sync_ddp(*args, **kwargs)
 
@@ -239,7 +239,7 @@ def sync_ddp(*args: Any, **kwargs: Any) -> Any:
 def sync_ddp_if_available(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.sync_ddp_if_available` has been deprecated in v1.8.0 and will"
-        " be removed in v1.10.0. This function is internal but you can copy over its implementation."
+        " be removed in v2.0.0. This function is internal but you can copy over its implementation."
     )
     return new_sync_ddp_if_available(*args, **kwargs)
 
@@ -247,9 +247,9 @@ def sync_ddp_if_available(*args: Any, **kwargs: Any) -> Any:
 def tpu_distributed() -> bool:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.tpu_distributed` has been deprecated in v1.8.0 and will"
-        " be removed in v1.10.0. This function is internal but you can copy over its implementation."
+        " be removed in v2.0.0. This function is internal but you can copy over its implementation."
     )
-    from lightning.lite.accelerators.tpu import _tpu_distributed
+    from lightning.fabric.accelerators.tpu import _tpu_distributed
 
     return _tpu_distributed()
 
@@ -257,7 +257,7 @@ def tpu_distributed() -> bool:
 def rank_zero_only(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.distributed.rank_zero_only` has been deprecated in v1.8.1 and will"
-        " be removed in v1.10.0. You can import it from `lightning.pytorch.utilities` instead."
+        " be removed in v2.0.0. You can import it from `lightning.pytorch.utilities` instead."
     )
     from lightning.pytorch.utilities.rank_zero import rank_zero_only as new_rank_zero_only
 
